MySnackbar class

A utility class that provides a simple way to show a SnackBar.

Constructors

MySnackbar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext context, String message, {Duration duration = const Duration(seconds: 3)}) → void
Displays a SnackBar with the given message in the provided context.